==> tuia-commercial-center-api-0.0.4-20190613.032719-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/user/BizActivityUserDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.user;

import java.io.Serializable;
import java.util.Date;

public class BizActivityUserDto implements Serializable {

    private static final long serialVersionUID = 6978156552687208674L;

    //"主键ID")
    private Integer id;

    //("用户表id")
    private Long bizUserId;

    //("媒体ID")
    private Long appId;

    //("活动类型")
    private Integer activityType;

    //("累计所得现金")
    private Long obtainCash;

    //("累计发券次数")
    private Integer couponTimes;

    //("累计登录天数")
    private Integer signDays;

    //("周期内累计登录天数")
    private Integer stageSignDays;

    //("连续登录天数")
    private Integer continuousSignDays;

    //("上次签到时间")
    private Date lastSignTime;

    //("已完成任务ID列表(JSON)")
    private String finishedMission;

    //("当日能够领取现金奖励的任务数量")
    private Integer cashMissionAmount;

    //("财务模型系数，每日更新")
    private Double coefficient;

    //("创建时间")
    private Date gmtCreate;

    //("修改时间")
    private Date gmtModified;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Long getBizUserId() {
        return bizUserId;
    }

    public void setBizUserId(Long bizUserId) {
        this.bizUserId = bizUserId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Long getObtainCash() {
        return obtainCash;
    }

    public void setObtainCash(Long obtainCash) {
        this.obtainCash = obtainCash;
    }

    public Integer getCouponTimes() {
        return couponTimes;
    }

    public void setCouponTimes(Integer couponTimes) {
        this.couponTimes = couponTimes;
    }

    public Integer getSignDays() {
        return signDays;
    }

    public void setSignDays(Integer signDays) {
        this.signDays = signDays;
    }

    public Integer getStageSignDays() {
        return stageSignDays;
    }

    public void setStageSignDays(Integer stageSignDays) {
        this.stageSignDays = stageSignDays;
    }

    public Integer getContinuousSignDays() {
        return continuousSignDays;
    }

    public void setContinuousSignDays(Integer continuousSignDays) {
        this.continuousSignDays = continuousSignDays;
    }

    public Date getLastSignTime() {
        return lastSignTime;
    }

    public void setLastSignTime(Date lastSignTime) {
        this.lastSignTime = lastSignTime;
    }

    public String getFinishedMission() {
        return finishedMission;
    }

    public void setFinishedMission(String finishedMission) {
        this.finishedMission = finishedMission;
    }

    public Integer getCashMissionAmount() {
        return cashMissionAmount;
    }

    public void setCashMissionAmount(Integer cashMissionAmount) {
        this.cashMissionAmount = cashMissionAmount;
    }

    public Double getCoefficient() {
        return coefficient;
    }

    public void setCoefficient(Double coefficient) {
        this.coefficient = coefficient;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}

==> tuia-commercial-center-api-1.0.3-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/user/BizActivityUserDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.user;

import java.io.Serializable;
import java.util.Date;

public class BizActivityUserDto implements Serializable {

    private static final long serialVersionUID = 6978156552687208674L;

    //"主键ID")
    private Integer id;

    //("用户表id")
    private Long bizUserId;

    //("媒体ID")
    private Long appId;

    //("活动类型")
    private Integer activityType;

    //("累计所得现金")
    private Long obtainCash;

    //("累计发券次数")
    private Integer couponTimes;

    //("累计登录天数")
    private Integer signDays;

    //("周期内累计登录天数")
    private Integer stageSignDays;

    //("连续登录天数")
    private Integer continuousSignDays;

    //("上次签到时间")
    private Date lastSignTime;

    //("已完成任务ID列表(JSON)")
    private String finishedMission;

    //("当日能够领取现金奖励的任务数量")
    private Integer cashMissionAmount;

    //("财务模型系数，每日更新")
    private Double coefficient;

    //("创建时间")
    private Date gmtCreate;

    //("修改时间")
    private Date gmtModified;

    /**
     * 剩余抽奖次数，一日5次
     * isNullAble:0,defaultVal:5
     */
    private Integer lotteryTimes;

    /**
     * 原生互动每日参与次数
     * isNullAble:0,defaultVal:0
     */
    private Integer curLotteryTimes;

    /**
     * 原生互动每日抽奖金币数
     * isNullAble:1
     */
    private Integer curLotteryCoins;

    /**
     * 原生互动抽奖奖励次数(JSON)
     * isNullAble:1,defaultVal:
     */
    private String lotteryPrizeTimes;

    /**
     * 记录各种首次时间JSON
     * isNullAble:1
     */
    private String firstTimeJson;

    private Integer curObtainCash;

    public Integer getCurObtainCash() {
        return curObtainCash;
    }

    public void setCurObtainCash(Integer curObtainCash) {
        this.curObtainCash = curObtainCash;
    }

    public Integer getLotteryTimes() {
        return lotteryTimes;
    }

    public void setLotteryTimes(Integer lotteryTimes) {
        this.lotteryTimes = lotteryTimes;
    }

    public Integer getCurLotteryTimes() {
        return curLotteryTimes;
    }

    public void setCurLotteryTimes(Integer curLotteryTimes) {
        this.curLotteryTimes = curLotteryTimes;
    }

    public Integer getCurLotteryCoins() {
        return curLotteryCoins;
    }

    public void setCurLotteryCoins(Integer curLotteryCoins) {
        this.curLotteryCoins = curLotteryCoins;
    }

    public String getLotteryPrizeTimes() {
        return lotteryPrizeTimes;
    }

    public void setLotteryPrizeTimes(String lotteryPrizeTimes) {
        this.lotteryPrizeTimes = lotteryPrizeTimes;
    }

    public String getFirstTimeJson() {
        return firstTimeJson;
    }

    public void setFirstTimeJson(String firstTimeJson) {
        this.firstTimeJson = firstTimeJson;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Long getBizUserId() {
        return bizUserId;
    }

    public void setBizUserId(Long bizUserId) {
        this.bizUserId = bizUserId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }

    public Long getObtainCash() {
        return obtainCash;
    }

    public void setObtainCash(Long obtainCash) {
        this.obtainCash = obtainCash;
    }

    public Integer getCouponTimes() {
        return couponTimes;
    }

    public void setCouponTimes(Integer couponTimes) {
        this.couponTimes = couponTimes;
    }

    public Integer getSignDays() {
        return signDays;
    }

    public void setSignDays(Integer signDays) {
        this.signDays = signDays;
    }

    public Integer getStageSignDays() {
        return stageSignDays;
    }

    public void setStageSignDays(Integer stageSignDays) {
        this.stageSignDays = stageSignDays;
    }

    public Integer getContinuousSignDays() {
        return continuousSignDays;
    }

    public void setContinuousSignDays(Integer continuousSignDays) {
        this.continuousSignDays = continuousSignDays;
    }

    public Date getLastSignTime() {
        return lastSignTime;
    }

    public void setLastSignTime(Date lastSignTime) {
        this.lastSignTime = lastSignTime;
    }

    public String getFinishedMission() {
        return finishedMission;
    }

    public void setFinishedMission(String finishedMission) {
        this.finishedMission = finishedMission;
    }

    public Integer getCashMissionAmount() {
        return cashMissionAmount;
    }

    public void setCashMissionAmount(Integer cashMissionAmount) {
        this.cashMissionAmount = cashMissionAmount;
    }

    public Double getCoefficient() {
        return coefficient;
    }

    public void setCoefficient(Double coefficient) {
        this.coefficient = coefficient;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}
